Cartographer_Import = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0")

local L = AceLibrary("AceLocale-2.2"):new("Cartographer_Import")

L:RegisterTranslations("enUS", function() return {
	["Added %s %s to %s at %.2f, %.2f from %s"] = true,
	
	["Mineral"] = true,
	["Herb"] = true,
	
	["Gatherer"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Added %s %s to %s at %.2f, %.2f from %s"] = "Added %s %s to %s at %.2f, %.2f from %s",

	["Mineral"] = "광물",
	["Herb"] = "약초",
	
	["Gatherer"] = "채집",
} end)

L:RegisterTranslations("zhTW", function() return {
	["Added %s %s to %s at %.2f, %.2f from %s"] = "加入 %s %s 到 %s 座標 %.2f, %.2f，來自 %s",
	
	["Mineral"] = "礦石",
	["Herb"] = "草藥",
	
	--["Gatherer"] = true,
} end)

local BZ = AceLibrary("Babble-Zone-2.2")

local zones = {
	[1] = {
		BZ["Ashenvale"],
		BZ["Azshara"],
		BZ["Darkshore"],
		BZ["Darnassus"],
		BZ["Desolace"],
		BZ["Durotar"],
		BZ["Dustwallow Marsh"],
		BZ["Felwood"],
		BZ["Feralas"],
		BZ["Moonglade"],
		BZ["Mulgore"],
		BZ["Orgrimmar"],
		BZ["Silithus"],
		BZ["Stonetalon Mountains"],
		BZ["Tanaris"],
		BZ["Teldrassil"],
		BZ["The Barrens"],
		BZ["Thousand Needles"],
		BZ["Thunder Bluff"],
		BZ["Un'Goro Crater"],
		BZ["Winterspring"],
	},
	[2] = {
		BZ["Alterac Mountains"],
		BZ["Arathi Highlands"],
		BZ["Badlands"],
		BZ["Blasted Lands"],
		BZ["Burning Steppes"],
		BZ["Deadwind Pass"],
		BZ["Dun Morogh"],
		BZ["Duskwood"],
		BZ["Eastern Plaguelands"],
		BZ["Elwynn Forest"],
		BZ["Hillsbrad Foothills"],
		BZ["Ironforge"],
		BZ["Loch Modan"],
		BZ["Redridge Mountains"],
		BZ["Searing Gorge"],
		BZ["Silverpine Forest"],
		BZ["Stormwind City"],
		BZ["Stranglethorn Vale"],
		BZ["Swamp of Sorrows"],
		BZ["The Hinterlands"],
		BZ["Tirisfal Glades"],
		BZ["Undercity"],
		BZ["Western Plaguelands"],
		BZ["Westfall"],
		BZ["Wetlands"],
	}
}
table.sort(zones[1])
table.sort(zones[2])

local gathererMineralsToCartographer = {
	["copper"] = "Copper",
	["tin"] = "Tin",
	["iron"] = "Iron",
	["iron"] = "Iron",
	["iron"] = "Iron",
	["silver"] = "Silver",
	["truesilver"] = "Truesilver",
	["gold"] = "Gold",
	["mithril"] = "Mithril",
	["thorium"] = "Thorium",
	["thorium (rich)"] = "Rich Thorium",
	["dark iron"] = "Dark Iron",
	
	["copper vein"] = "Copper",
	["tin vein"] = "Tin",
	["iron deposit"] = "Iron",
	["silver vein"] = "Silver",
	["truesilver deposit"] = "Truesilver",
	["gold vein"] = "Gold",
	["mithril deposit"] = "Mithril",
	["small thorium vein"] = "Thorium",
	["rich thorium vein"] = "Rich Thorium",
	["dark iron deposit"] = "Dark Iron",
}

local gathererHerbsToCartographer = {
	["arthas' tears"] = "Arthas' Tears",
	["black lotus"] = "Black Lotus",
	["blindweed"] = "Blindweed",
	["briarthorn"] = "Briarthorn",
	["bruiseweed"] = "Bruiseweed",
	["dreamfoil"] = "Dreamfoil",
	["earthroot"] = "Earthroot",
	["fadeleaf"] = "Fadeleaf",
	["firebloom"] = "Firebloom",
	["ghost mushroom"] = "Ghost Mushroom",
	["golden sansam"] = "Golden Sansam",
	["goldthorn"] = "Goldthorn",
	["grave moss"] = "Grave Moss",
	["gromsblood"] = "Gromsblood",
	["icecap"] = "Icecap",
	["khadgar's whisker"] = "Khadgar's Whisker",
	["kingsblood"] = "Kingsblood",
	["liferoot"] = "Liferoot",
	["mageroyal"] = "Mageroyal",
	["mountain silversage"] = "Mountain Silversage",
	["peacebloom"] = "Peacebloom",
	["plaguebloom"] = "Plaguebloom",
	["purple lotus"] = "Purple Lotus",
	["silverleaf"] = "Silverleaf",
	["stranglekelp"] = "Stranglekelp",
	["sungrass"] = "Sungrass",
	["swiftthistle"] = "Swiftthistle",
	["wild steelbloom"] = "Wild Steelbloom",
	["wintersbite"] = "Wintersbite",
	["wildvine"] ="Wildvine"
}

function Cartographer_Import:OnEnable()
	local hasMining = Cartographer:HasModule(AceLibrary("Babble-Spell-2.2")["Mining"])
	local hasHerb = Cartographer:HasModule(AceLibrary("Babble-Spell-2.2")["Herbalism"])
	if GatherItems then
		for continent, cdata in pairs(GatherItems) do
			for zone, zdata in pairs(cdata) do
				local zname = BZ:GetReverseTranslation(zones[continent][zone])
				for item, idata in pairs(zdata) do
					if gathererMineralsToCartographer[item] and hasMining then
						for _,v in ipairs(idata) do
							if Cartographer_Notes:SetNote(zname, v.x/100, v.y/100, gathererMineralsToCartographer[item], "Mining") then
								self:Print(L["Added %s %s to %s at %.2f, %.2f from %s"], L["Mineral"], gathererMineralsToCartographer[item], zname, v.x, v.y, "Gatherer")
							end
						end
					elseif gathererHerbsToCartographer[item] and hasHerb then
						for _,v in ipairs(idata) do
							if Cartographer_Notes:SetNote(zname, v.x/100, v.y/100, gathererHerbsToCartographer[item], "Herbalism") then
								self:Print(L["Added %s %s to %s at %.2f, %.2f from %s"], L["Herb"], gathererHerbsToCartographer[item], zname, v.x, v.y, "Gatherer")
							end
						end
					end
				end
			end
		end
	end
	self:Print("Done importing notes")
end
